<!-- PLEASE READ THE FOLLOWING INSTRUCTIONS -->

<!-- Choose one of the following: -->
This is about **Bulma | the Docs**.

<!-- Is it about Bulma or about the Docs? -->
<!-- Is it a bug/feature/question or do you need help? -->
<!-- If it's a bug, is it a browser bug? -->

### Overview of the problem

<!-- UNCOMMENT THE APPROPRIATE LINES -->

<!-- This is about the Bulma **CSS framework** -->
<!-- This is about the Bulma **Docs** -->
<!-- I'm using Bulma **version** [x.x.x] -->
<!-- My **browser** is: -->
<!-- This is a **Sass** issue: I'm using version [x.x.x] -->
<!-- I am sure this issue is **not a duplicate**? -->

### Description

<!-- Description of the bug, enhancement, or question -->

### Steps to Reproduce

<!--
1. First Step
2. Second Step
3. and so on...
-->

### Expected behavior

<!-- What you expected to happen -->

### Actual behavior

<!-- What actually happened -->
